@@ -2,10 +2,10 @@
 #' @name igo_search_states
 #' @description Extract all the memberships of a state on a specific date.
 #' @return A dataframe.
-#' @seealso \code{\link{states2016}}.
+#' @seealso [states2016()].
 #'
 #' @param state Any valid name or code of a state as specified on
-#' \code{\link{states2016}}. It could be also an array of states.
+#' [states2016()]. It could be also an array of states.
 #'
 #' @examples
 #' igo_search_states("Spain")
@@ -38,17 +38,19 @@ igo_search_states <- function(state) {
     find_state <- sort(find_state)[1]
 
     if (is.na(find_state)) {
-      stop("state not found: ",
-           paste0("'",
-                  state[1],
-                  "'",
-                  collapse = ", "))
+      stop(
+        "state not found: ",
+        paste0("'",
+          state[1],
+          "'",
+          collapse = ", "
+        )
+      )
     }
 
     df_states <- df_states[find_state, ]
 
     return(df_states)
-
   } else {
     # Vectorized ----
     df <- igo_search_states(state[1])
@@ -60,6 +62,5 @@ igo_search_states <- function(state) {
     }
 
     return(df)
-
   }
 }
